Crate dioxus_fullstack
source ·Expand description
Dioxus Fullstack
Website | Guides | API Docs | Chat
Fullstack utilities for the Dioxus framework.
Features
- Integrates with the Axum server framework with utilities for serving and rendering Dioxus applications.
- Server functions allow you to call code on the server from the client as if it were a normal function.
- Instant RSX Hot reloading with
dioxus-hot-reload. - Passing root props from the server to the client.
Example
Full stack Dioxus in under 30 lines of code
#![allow(non_snake_case)]
use dioxus::prelude::*;
fn main() {
launch(App);
}
#[component]
fn App() -> Element {
let mut meaning = use_signal(|| None);
rsx! {
h1 { "Meaning of life: {meaning:?}" }
button {
onclick: move |_| async move {
if let Ok(data) = get_meaning("life the universe and everything".into()).await {
meaning.set(data);
}
},
"Run a server function"
}
}
}
#[server]
async fn get_meaning(of: String) -> Result<Option<u32>, ServerFnError> {
Ok(of.contains("life").then(|| 42))
}Getting Started
To get started with full stack Dioxus, check out our getting started guide, or the full stack examples.
Contributing
- Report issues on our issue tracker.
- Join the discord and ask questions!
License
This project is licensed under the MIT license.
Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in Dioxus by you shall be licensed as MIT without any additional terms or conditions.
Re-exports
pub use once_cell;
Modules
- This module contains the document providers for the fullstack platform.
- This module contains the
launchfunction, which is the main entry point for dioxus fullstack - A prelude of commonly used items in dioxus-fullstack.
Structs
- Settings for a fullstack app.
- Used to configure how to serve a Dioxus application. It contains information about how to serve static assets, and what content to render with [
dioxus-ssr]. SeeServeConfigBuilderto create a ServeConfig - A ServeConfig is used to configure how to serve a Dioxus application. It contains information about how to serve static assets, and what content to render with [
dioxus-ssr].