Module body

Module body 

Re-export commonly used items from axum, http, and hyper for convenience. HTTP body utilities.

Re-exports

pub use body::Body as HttpBody;
pub use body::Bytes;

Structs

Body
The body type used in axum requests and responses.
BodyDataStream
A stream of data frames.

Functions

to_bytes
Converts Body into Bytes and limits the maximum size of the body.