pub struct ByteStream<E = ServerFnError>(/* private fields */);Expand description
A stream of bytes.
A server function can return this type if its output encoding is Streaming.
Browser Support for Streaming Input
Browser fetch requests do not currently support full request duplexing, which means that that they do begin handling responses until the full request has been sent. This means that if you use a streaming input encoding, the input stream needs to end before the output will begin.
Streaming requests are only allowed over HTTP2 or HTTP3.
Implementations
Sourceimpl<E> ByteStream<E>
impl<E> ByteStream<E>