Module dioxus_fullstack::document

source ·
This module contains the document providers for the fullstack platform.

Structs

  • A Document provider that collects all contents injected into the head for SSR rendering.