ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind { WrongNumberOfParameters { got: usize, expected: usize, }, ParseErrorAtKey { key: String, value: String, expected_type: &'static str, }, ParseErrorAtIndex { index: usize, value: String, expected_type: &'static str, }, ParseError { value: String, expected_type: &'static str, }, InvalidUtf8InPathParam { key: String, }, UnsupportedType { name: &'static str, }, DeserializeError { key: String, value: String, message: String, }, Message(String), }
The kinds of errors that can happen we deserializing into a Path.

This type is obtained through FailedToDeserializePathParams::kind or FailedToDeserializePathParams::into_kind and is useful for building more precise error messages.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


WrongNumberOfParameters

The URI contained the wrong number of parameters.

Fields

got: usize

The number of actual parameters in the URI.

expected: usize

The number of expected parameters.



ParseErrorAtKey

Failed to parse the value at a specific key into the expected type.

This variant is used when deserializing into types that have named fields, such as structs.

Fields

key: String

The key at which the value was located.

value: String

The value from the URI.

expected_type: &'static str

The expected type of the value.



ParseErrorAtIndex

Failed to parse the value at a specific index into the expected type.

This variant is used when deserializing into sequence types, such as tuples.

Fields

index: usize

The index at which the value was located.

value: String

The value from the URI.

expected_type: &'static str

The expected type of the value.



ParseError

Failed to parse a value into the expected type.

This variant is used when deserializing into a primitive type (such as String and u32).

Fields

value: String

The value from the URI.

expected_type: &'static str

The expected type of the value.



InvalidUtf8InPathParam

A parameter contained text that, once percent decoded, wasn’t valid UTF-8.

Fields

key: String

The key at which the invalid value was located.



UnsupportedType

Tried to serialize into an unsupported type such as nested maps.

This error kind is caused by programmer errors and thus gets converted into a 500 Internal Server Error response.

Fields

name: &'static str

The name of the unsupported type.



DeserializeError

Failed to deserialize the value with a custom deserialization error.

Fields

key: String

The key at which the invalid value was located.

value: String

The value that failed to deserialize.

message: String

The deserializaation failure message.



Message(String)

Catch-all variant for errors that don’t fit any other variant.