pub enum ServerFnError<E = NoCustomError> {
WrappedServerError(E),
Registration(String),
Request(String),
Response(String),
ServerError(String),
MiddlewareError(String),
Deserialization(String),
Serialization(String),
Args(String),
MissingArg(String),
}Expand description
A type that can be used as the return type of the server function for easy error conversion with ? operator.
This type can be replaced with any other error type that implements FromServerFnError.
Unlike ServerFnErrorErr, this does not implement Error.
This means that other error types can easily be converted into it using the
? operator.
Variants
WrappedServerError(E)
A user-defined custom error type, which defaults to NoCustomError.
Registration(String)
Error while trying to register the server function (only occurs in case of poisoned RwLock).
Request(String)
Occurs on the client if there is a network error while trying to run function on server.
Response(String)
Occurs on the server if there is an error creating an HTTP response.
ServerError(String)
Occurs when there is an error while actually running the function on the server.
MiddlewareError(String)
Occurs when there is an error while actually running the middleware on the server.
Deserialization(String)
Occurs on the client if there is an error deserializing the server’s response.
Serialization(String)
Occurs on the client if there is an error serializing the server function arguments.
Args(String)
Occurs on the server if there is an error deserializing one of the arguments that’s been sent.
MissingArg(String)
Occurs on the server if there’s a missing argument.
Implementations
Sourceimpl ServerFnError
impl ServerFnError
Sourcepub fn new(msg: impl ToString) -> ServerFnError
pub fn new(msg: impl ToString) -> ServerFnError
Constructs a new ServerFnError::ServerError from some other type.