pub fn server_context() -> DioxusServerContextAvailable on crate feature
server only.Expand description
Get information about the current server request.
This function will only provide the current server context if it is called from a server function or on the server rendering a request.