pub struct ServerFnTraitObj<Req, Res> { /* private fields */ }Expand description
A trait object that allows multiple server functions that take the same request type and return the same response type to be gathered into a single collection.
Implementations
Sourceimpl<Req, Res> ServerFnTraitObj<Req, Res>
impl<Req, Res> ServerFnTraitObj<Req, Res>
Sourcepub const fn new<S>(
handler: fn(Req) -> Pin<Box<dyn Future<Output = Res> + Send>>,
) -> ServerFnTraitObj<Req, Res>where
S: ServerFn,
<S as ServerFn>::Server: Server<<S as ServerFn>::Error, <S as ServerFn>::InputStreamError, <S as ServerFn>::OutputStreamError, Request = Req, Response = Res>,
Req: Req<<S as ServerFn>::Error, <S as ServerFn>::InputStreamError, <S as ServerFn>::OutputStreamError, WebsocketResponse = Res> + Send + 'static,
Res: TryRes<<S as ServerFn>::Error> + Send + 'static,
pub const fn new<S>(
handler: fn(Req) -> Pin<Box<dyn Future<Output = Res> + Send>>,
) -> ServerFnTraitObj<Req, Res>where
S: ServerFn,
<S as ServerFn>::Server: Server<<S as ServerFn>::Error, <S as ServerFn>::InputStreamError, <S as ServerFn>::OutputStreamError, Request = Req, Response = Res>,
Req: Req<<S as ServerFn>::Error, <S as ServerFn>::InputStreamError, <S as ServerFn>::OutputStreamError, WebsocketResponse = Res> + Send + 'static,
Res: TryRes<<S as ServerFn>::Error> + Send + 'static,
Converts the relevant parts of a server function into a trait object.
Sourcepub fn handler(&self, req: Req) -> impl Future<Output = Res> + Send
pub fn handler(&self, req: Req) -> impl Future<Output = Res> + Send
The handler for this server function.
Sourcepub fn middleware(&self) -> Vec<Arc<dyn Layer<Req, Res>>>
pub fn middleware(&self) -> Vec<Arc<dyn Layer<Req, Res>>>
The set of middleware that should be applied to this function.
Sourcepub fn boxed(self) -> BoxedService<Req, Res>where
ServerFnTraitObj<Req, Res>: Service<Req, Res>,
Req: 'static,
Res: 'static,
pub fn boxed(self) -> BoxedService<Req, Res>where
ServerFnTraitObj<Req, Res>: Service<Req, Res>,
Req: 'static,
Res: 'static,
Converts the server function into a boxed service.