Struct dioxus_fullstack::ServeConfig
source · pub struct ServeConfig { /* private fields */ }Expand description
Used to configure how to serve a Dioxus application. It contains information about how to serve static assets, and what content to render with [dioxus-ssr].
See ServeConfigBuilder to create a ServeConfig
Implementations
sourceimpl ServeConfig
impl ServeConfig
sourcepub fn builder() -> ServeConfigBuilder
pub fn builder() -> ServeConfigBuilder
Create a new builder for a ServeConfig