Struct dioxus_fullstack::ServeConfigBuilder
source · pub struct ServeConfigBuilder { /* private fields */ }Expand description
A ServeConfig is used to configure how to serve a Dioxus application. It contains information about how to serve static assets, and what content to render with [dioxus-ssr].
Implementations
sourceimpl ServeConfigBuilder
impl ServeConfigBuilder
sourcepub fn new() -> Self
pub fn new() -> Self
Create a new ServeConfigBuilder with the root component and props to render on the server.
sourcepub fn incremental(self, cfg: IncrementalRendererConfig) -> Self
pub fn incremental(self, cfg: IncrementalRendererConfig) -> Self
Enable incremental static generation
sourcepub fn index_html(self, index_html: String) -> Self
pub fn index_html(self, index_html: String) -> Self
Set the contents of the index.html file to be served. (precedence over index_path)
sourcepub fn index_path(self, index_path: PathBuf) -> Self
pub fn index_path(self, index_path: PathBuf) -> Self
Set the path of the index.html file to be served. (defaults to {assets_path}/index.html)
sourcepub fn root_id(self, root_id: &'static str) -> Self
pub fn root_id(self, root_id: &'static str) -> Self
Set the id of the root element in the index.html file to place the prerendered content into. (defaults to main)
sourcepub fn build(self) -> ServeConfig
pub fn build(self) -> ServeConfig
Build the ServeConfig