Re-export commonly used items from axum, http, and hyper for convenience. HTTP body utilities.
Re-exports
pub use body::Body as HttpBody;pub use body::Bytes;
Structs
- Body
- The body type used in axum requests and responses.
- Body
Data Stream - A stream of data frames.