dioxus_fullstack

Module prelude

A prelude of commonly used items in dioxus-fullstack.

Re-exports

Structs

  • Axumserver and axum
    An adapter for axum extractors for the server context
  • A shared context for server functions that contains information about the request and middleware state.
  • Extract a value from the server context provided through the launch builder context or DioxusServerContext::insert
  • The template that wraps the body of the HTML for a fullstack page. This template contains the data needed to hydrate server functions that were run on the server.
  • An incremental renderer.
  • A configuration for the incremental renderer.
  • A future that provides the server context to the inner future
  • SSRStateserver
    State used in server side rendering. This utilizes a pool of dioxus_ssr::Renderers to cache static templates between renders.
  • Used to configure how to serve a Dioxus application. It contains information about how to serve static assets, and what content to render with [dioxus-ssr]. See ServeConfigBuilder to create a ServeConfig
  • A ServeConfig is used to configure how to serve a Dioxus application. It contains information about how to serve static assets, and what content to render with [dioxus-ssr].

Enums

  • Type for errors that can occur when using server functions.

Traits

Functions

  • extractserver
    Extract some part from the current server request.
  • Get information about the current server request.
  • This allows you to send data from the server to the client. The data is serialized into the HTML on the server and hydrated on the client.
  • Runs a future with a manual list of dependencies and returns a resource with the result if the future is finished or a suspended error if it is still running.
  • Run a function inside of the server context.

Attribute Macros

  • Declares that a function is a server function. This means that its body will only run on the server, i.e., when the ssr feature is enabled on this crate.