A prelude of commonly used items in dioxus-fullstack.
Re-exports
Structs
- Axum
serverandaxumAn adapter for axum extractors for the server context - Dioxus
Server Context serverA shared context for server functions that contains information about the request and middleware state. - From
Context serverExtract a value from the server context provided through the launch builder context orDioxusServerContext::insert - FullstackHTML
Template serverThe template that wraps the body of the HTML for a fullstack page. This template contains the data needed to hydrate server functions that were run on the server. - Incremental
Renderer serverAn incremental renderer. - A configuration for the incremental renderer.
- Provide
Server Context serverA future that provides the server context to the inner future - SSRState
serverState used in server side rendering. This utilizes a pool ofdioxus_ssr::Renderers to cache static templates between renders. - Serve
Config serverUsed to configure how to serve a Dioxus application. It contains information about how to serve static assets, and what content to render with [dioxus-ssr]. SeeServeConfigBuilderto create a ServeConfig - Serve
Config Builder serverA ServeConfig is used to configure how to serve a Dioxus application. It contains information about how to serve static assets, and what content to render with [dioxus-ssr].
Enums
- Type for errors that can occur when using server functions.
Traits
- From
Server Context serverA trait for extracting types from the server context
Functions
- extract
serverExtract some part from the current server request. - server_
context serverGet information about the current server request. - This allows you to send data from the server to the client. The data is serialized into the HTML on the server and hydrated on the client.
- Runs a future with a manual list of dependencies and returns a resource with the result if the future is finished or a suspended error if it is still running.
- with_
server_ context serverRun a function inside of the server context.
Attribute Macros
- Declares that a function is a server function. This means that its body will only run on the server, i.e., when the
ssrfeature is enabled on this crate.