pub struct WrapError<T>(pub T);๐Deprecated since 0.8.0: Now server_fn can return any error type other than ServerFnError, so the WrappedServerError variant will be removed in 0.9.0
Tuple Fields
0: T๐Deprecated since 0.8.0: Now server_fn can return any error type other than ServerFnError, so the WrappedServerError variant will be removed in 0.9.0